@@ -190,16 +190,18 @@ class LibraryExperiment(object):
             
         # normalize count matrix to counts per million
         normalized_count_mat = self.count_mat.copy()
-        counts = normalized_count_mat[self.pools].values.astype(float)
-        counts = (counts/np.sum(counts, axis=0))*1e6
-        normalized_count_mat[self.pools] = counts
+        normalized_count_mat_ = normalized_count_mat.copy()
+        counts = normalized_count_mat_[self.pools].values.astype(float)
         
-        self.normalized_count_mat = normalized_count_mat
+        counts = (counts/np.sum(counts, axis=0))*1e6
+        normalized_count_mat_[self.pools] = counts
+        
+        self.normalized_count_mat = normalized_count_mat_
         
         # apply count filters to reduce noise
         counts = global_filter_counts(counts, thr=self.global_filter_thr)
         counts = local_filter_counts(counts, thr=self.filter_thr)
-        filtered_count_mat = normalized_count_mat.copy()
+        filtered_count_mat = normalized_count_mat_.copy()
         filtered_count_mat[self.pools] = counts
         self.filtered_count_mat = filtered_count_mat
         
